@@ -35,8 +35,7 @@ class ColorizedArgsFormatter(logging.Formatter):
             _format = fmt
             for fld in ColorizedArgsFormatter.level_fields:
                 search = "(%\(" + fld + "\).*?s)"
-                _format = re.sub(
-                    search, f"{color}\\1{ColorCodes.reset}", _format)
+                _format = re.sub(search, f"{color}\\1{ColorCodes.reset}", _format)
             formatter = logging.Formatter(_format)
             self.level_to_formatter[level] = formatter
 
@@ -60,8 +59,7 @@ class ColorizedArgsFormatter(logging.Formatter):
         while True:
             if "_{{" not in msg:
                 break
-            color_index = placeholder_count % len(
-                ColorizedArgsFormatter.arg_colors)
+            color_index = placeholder_count % len(ColorizedArgsFormatter.arg_colors)
             color = ColorizedArgsFormatter.arg_colors[color_index]
             msg = msg.replace("_{{", color + "{", 1)
             msg = msg.replace("_}}", "}" + ColorCodes.reset, 1)
@@ -94,7 +92,7 @@ class BraceFormatStyleFormatter(logging.Formatter):
             return False
 
         msg = record.msg
-        if '%' in msg:
+        if "%" in msg:
             return False
 
         count_of_start_param = msg.count("{")
